pub struct DnsConfig {
pub pre_connection: DohServerConfig,
pub post_connection: DohServerConfig,
}Expand description
DNS configuration for the library.
Allows configuring different DNS servers for pre-connection (direct mode) and post-connection (tunnel mode) DNS resolution.
Fields
pre_connection: DohServerConfigDNS server to use before the WireGuard tunnel is established. This is used to resolve the WireGuard endpoint hostname.
post_connection: DohServerConfigDNS server to use after the WireGuard tunnel is established. All DNS queries will go through the VPN tunnel.
Implementations
Sourceimpl DnsConfig
impl DnsConfig
Sourcepub fn new(server: DohServerConfig) -> Self
pub fn new(server: DohServerConfig) -> Self
Create a new DNS configuration with the same server for both modes.
Sourcepub fn with_different_servers(
pre_connection: DohServerConfig,
post_connection: DohServerConfig,
) -> Self
pub fn with_different_servers( pre_connection: DohServerConfig, post_connection: DohServerConfig, ) -> Self
Create a DNS configuration with different servers for pre and post connection.
Sourcepub fn cloudflare() -> Self
pub fn cloudflare() -> Self
Use Cloudflare DNS for both modes (default).