NetStack

Struct NetStack 

pub struct NetStack { /* private fields */ }
A userspace TCP/IP network stack.

Implementations

Source

impl NetStack

pub fn new(wg_tunnel: Arc<WireGuardTunnel>) -> Arc<Self>

Create a new network stack backed by a WireGuard tunnel.

pub fn create_tcp_socket(&self) -> SocketHandle

Create a new TCP socket and return its handle.

pub fn connect(&self, handle: SocketHandle, addr: SocketAddr) -> Result<()>

Connect a TCP socket to the given address.

pub fn is_connected(&self, handle: SocketHandle) -> bool

Check if a TCP socket is connected.

pub fn can_send(&self, handle: SocketHandle) -> bool

Check if a TCP socket can send data.

pub fn can_recv(&self, handle: SocketHandle) -> bool

Check if a TCP socket can receive data.

pub fn may_send(&self, handle: SocketHandle) -> bool

Check if a TCP socket may send data (connection in progress or established).

pub fn may_recv(&self, handle: SocketHandle) -> bool

Check if a TCP socket may receive data.

pub fn socket_state(&self, handle: SocketHandle) -> TcpState

Get the TCP socket state.

pub fn send(&self, handle: SocketHandle, data: &[u8]) -> Result<usize>

Send data on a TCP socket.

pub fn recv(&self, handle: SocketHandle, buffer: &mut [u8]) -> Result<usize>

Receive data from a TCP socket.

pub fn close(&self, handle: SocketHandle)

Close a TCP socket.

pub fn remove_socket(&self, handle: SocketHandle)

Remove a socket from the socket set.

pub fn poll(&self) -> bool

Poll the network stack, processing packets and updating socket states. Returns true if there was any activity.

pub fn push_rx_packet(&self, packet: BytesMut)

Push a received packet (from WireGuard) into the network stack.

pub async fn run_poll_loop(self: &Arc<Self>) -> Result<()>

Run the network stack polling loop.

pub async fn run_rx_loop(self: &Arc<Self>, rx: Receiver<BytesMut>) -> Result<()>

Run the receive loop that takes packets from WireGuard and feeds them to the stack.